# setup.py needs to import this without worrying about required packages being
# installed. So if you add imports here, you may need to do something like:
# https://github.com/mitsuhiko/click/blob/da080dd2de1a116fc5789ffdc1ec6ffb864f2044/setup.py#L1-L11
__version__ = '0.8.0'
